#!/usr/bin/env python

# Uncomment and adjust the paths below if WebStack is not installed somewhere
# on the PYTHONPATH.

#import sys
#sys.path.append("/home/paulb/Software/Python/WebStack")
#sys.path.append("/home/paulb/Software/Python/WebStack/examples/Common")

from WebStack.Adapters.WSGI import deploy_as_cgi
from VerySimple import VerySimpleResource

deploy_as_cgi(VerySimpleResource(), handle_errors=0)

# vim: tabstop=4 expandtab shiftwidth=4
